/* Arabic */
#define LANGUAGE_PROGRESS_ARABIC_TRANSLATED 43
#define LANGUAGE_PROGRESS_ARABIC_APPROVED   0

/* Asturian */
#define LANGUAGE_PROGRESS_ASTURIAN_TRANSLATED 13
#define LANGUAGE_PROGRESS_ASTURIAN_APPROVED   12

/* Belarusian */
#define LANGUAGE_PROGRESS_BELARUSIAN_TRANSLATED 94
#define LANGUAGE_PROGRESS_BELARUSIAN_APPROVED   0

/* Bulgarian */
#define LANGUAGE_PROGRESS_BULGARIAN_TRANSLATED 2
#define LANGUAGE_PROGRESS_BULGARIAN_APPROVED   0

/* Catalan */
#define LANGUAGE_PROGRESS_CATALAN_TRANSLATED 100
#define LANGUAGE_PROGRESS_CATALAN_APPROVED   0

/* Czech */
#define LANGUAGE_PROGRESS_CZECH_TRANSLATED 95
#define LANGUAGE_PROGRESS_CZECH_APPROVED   0

/* Welsh */
#define LANGUAGE_PROGRESS_WELSH_TRANSLATED 3
#define LANGUAGE_PROGRESS_WELSH_APPROVED   0

/* Danish */
#define LANGUAGE_PROGRESS_DANISH_TRANSLATED 3
#define LANGUAGE_PROGRESS_DANISH_APPROVED   0

/* German */
#define LANGUAGE_PROGRESS_GERMAN_TRANSLATED 99
#define LANGUAGE_PROGRESS_GERMAN_APPROVED   13

/* Greek */
#define LANGUAGE_PROGRESS_GREEK_TRANSLATED 20
#define LANGUAGE_PROGRESS_GREEK_APPROVED   0

/* English, United Kingdom */
#define LANGUAGE_PROGRESS_ENGLISH_UNITED_KINGDOM_TRANSLATED 94
#define LANGUAGE_PROGRESS_ENGLISH_UNITED_KINGDOM_APPROVED   0

/* Esperanto */
#define LANGUAGE_PROGRESS_ESPERANTO_TRANSLATED 2
#define LANGUAGE_PROGRESS_ESPERANTO_APPROVED   0

/* Spanish */
#define LANGUAGE_PROGRESS_SPANISH_TRANSLATED 100
#define LANGUAGE_PROGRESS_SPANISH_APPROVED   94

/* Persian */
#define LANGUAGE_PROGRESS_PERSIAN_TRANSLATED 11
#define LANGUAGE_PROGRESS_PERSIAN_APPROVED   0

/* Finnish */
#define LANGUAGE_PROGRESS_FINNISH_TRANSLATED 73
#define LANGUAGE_PROGRESS_FINNISH_APPROVED   43

/* French */
#define LANGUAGE_PROGRESS_FRENCH_TRANSLATED 100
#define LANGUAGE_PROGRESS_FRENCH_APPROVED   100

/* Irish */
#define LANGUAGE_PROGRESS_IRISH_TRANSLATED 100
#define LANGUAGE_PROGRESS_IRISH_APPROVED   0

/* Galician */
#define LANGUAGE_PROGRESS_GALICIAN_TRANSLATED 99
#define LANGUAGE_PROGRESS_GALICIAN_APPROVED   0

/* Hebrew */
#define LANGUAGE_PROGRESS_HEBREW_TRANSLATED 3
#define LANGUAGE_PROGRESS_HEBREW_APPROVED   0

/* Croatian */
#define LANGUAGE_PROGRESS_CROATIAN_TRANSLATED 2
#define LANGUAGE_PROGRESS_CROATIAN_APPROVED   0

/* Hungarian */
#define LANGUAGE_PROGRESS_HUNGARIAN_TRANSLATED 100
#define LANGUAGE_PROGRESS_HUNGARIAN_APPROVED   0

/* Indonesian */
#define LANGUAGE_PROGRESS_INDONESIAN_TRANSLATED 17
#define LANGUAGE_PROGRESS_INDONESIAN_APPROVED   0

/* Italian */
#define LANGUAGE_PROGRESS_ITALIAN_TRANSLATED 99
#define LANGUAGE_PROGRESS_ITALIAN_APPROVED   0

/* Japanese */
#define LANGUAGE_PROGRESS_JAPANESE_TRANSLATED 91
#define LANGUAGE_PROGRESS_JAPANESE_APPROVED   0

/* Korean */
#define LANGUAGE_PROGRESS_KOREAN_TRANSLATED 99
#define LANGUAGE_PROGRESS_KOREAN_APPROVED   0

/* Dutch */
#define LANGUAGE_PROGRESS_DUTCH_TRANSLATED 35
#define LANGUAGE_PROGRESS_DUTCH_APPROVED   0

/* Norwegian */
#define LANGUAGE_PROGRESS_NORWEGIAN_TRANSLATED 18
#define LANGUAGE_PROGRESS_NORWEGIAN_APPROVED   0

/* Odia */
#define LANGUAGE_PROGRESS_ODIA_TRANSLATED 0
#define LANGUAGE_PROGRESS_ODIA_APPROVED   0

/* Polish */
#define LANGUAGE_PROGRESS_POLISH_TRANSLATED 75
#define LANGUAGE_PROGRESS_POLISH_APPROVED   21

/* Portuguese, Brazilian */
#define LANGUAGE_PROGRESS_PORTUGUESE_BRAZILIAN_TRANSLATED 99
#define LANGUAGE_PROGRESS_PORTUGUESE_BRAZILIAN_APPROVED   8

/* Portuguese */
#define LANGUAGE_PROGRESS_PORTUGUESE_TRANSLATED 29
#define LANGUAGE_PROGRESS_PORTUGUESE_APPROVED   0

/* Russian */
#define LANGUAGE_PROGRESS_RUSSIAN_TRANSLATED 100
#define LANGUAGE_PROGRESS_RUSSIAN_APPROVED   12

/* Slovak */
#define LANGUAGE_PROGRESS_SLOVAK_TRANSLATED 20
#define LANGUAGE_PROGRESS_SLOVAK_APPROVED   0

/* Serbian (Latin) */
#define LANGUAGE_PROGRESS_SERBIAN_LATIN_TRANSLATED 7
#define LANGUAGE_PROGRESS_SERBIAN_LATIN_APPROVED   0

/* Swedish */
#define LANGUAGE_PROGRESS_SWEDISH_TRANSLATED 98
#define LANGUAGE_PROGRESS_SWEDISH_APPROVED   65

/* Turkish */
#define LANGUAGE_PROGRESS_TURKISH_TRANSLATED 99
#define LANGUAGE_PROGRESS_TURKISH_APPROVED   99

/* Tatar */
#define LANGUAGE_PROGRESS_TATAR_TRANSLATED 0
#define LANGUAGE_PROGRESS_TATAR_APPROVED   0

/* Ukrainian */
#define LANGUAGE_PROGRESS_UKRAINIAN_TRANSLATED 100
#define LANGUAGE_PROGRESS_UKRAINIAN_APPROVED   6

/* Valencian */
#define LANGUAGE_PROGRESS_VALENCIAN_TRANSLATED 14
#define LANGUAGE_PROGRESS_VALENCIAN_APPROVED   0

/* Vietnamese */
#define LANGUAGE_PROGRESS_VIETNAMESE_TRANSLATED 99
#define LANGUAGE_PROGRESS_VIETNAMESE_APPROVED   0

/* Chinese Simplified */
#define LANGUAGE_PROGRESS_CHINESE_SIMPLIFIED_TRANSLATED 99
#define LANGUAGE_PROGRESS_CHINESE_SIMPLIFIED_APPROVED   41

/* Chinese Traditional */
#define LANGUAGE_PROGRESS_CHINESE_TRADITIONAL_TRANSLATED 87
#define LANGUAGE_PROGRESS_CHINESE_TRADITIONAL_APPROVED   70

